==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/GetDefaultAdminRulePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.GetDefaultAdminRulePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property configurationName The name of the network manager Security Configuration.
 * @property networkManagerName The name of the network manager.
 * @property resourceGroupName The name of the resource group.
 * @property ruleCollectionName The name of the network manager security Configuration rule collection.
 * @property ruleName The name of the rule.
 */
public data class GetDefaultAdminRulePlainArgs(
    public val configurationName: String,
    public val networkManagerName: String,
    public val resourceGroupName: String,
    public val ruleCollectionName: String,
    public val ruleName: String,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.GetDefaultAdminRulePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.GetDefaultAdminRulePlainArgs =
        com.pulumi.azurenative.network.inputs.GetDefaultAdminRulePlainArgs.builder()
            .configurationName(configurationName.let({ args0 -> args0 }))
            .networkManagerName(networkManagerName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .ruleCollectionName(ruleCollectionName.let({ args0 -> args0 }))
            .ruleName(ruleName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetDefaultAdminRulePlainArgs].
 */
@PulumiTagMarker
public class GetDefaultAdminRulePlainArgsBuilder internal constructor() {
    private var configurationName: String? = null

    private var networkManagerName: String? = null

    private var resourceGroupName: String? = null

    private var ruleCollectionName: String? = null

    private var ruleName: String? = null

    /**
     * @param value The name of the network manager Security Configuration.
     */
    @JvmName("bsvtpfshfadrskqq")
    public suspend fun configurationName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.configurationName = mapped
    }

    /**
     * @param value The name of the network manager.
     */
    @JvmName("bynlknjfacwwylme")
    public suspend fun networkManagerName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.networkManagerName = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("bvrpregqgskpvmcl")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the network manager security Configuration rule collection.
     */
    @JvmName("xxbwwlbmhaqpawvq")
    public suspend fun ruleCollectionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.ruleCollectionName = mapped
    }

    /**
     * @param value The name of the rule.
     */
    @JvmName("gymgrfgdorctlatx")
    public suspend fun ruleName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.ruleName = mapped
    }

    internal fun build(): GetDefaultAdminRulePlainArgs = GetDefaultAdminRulePlainArgs(
        configurationName = configurationName ?: throw PulumiNullFieldException("configurationName"),
        networkManagerName = networkManagerName ?: throw PulumiNullFieldException("networkManagerName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        ruleCollectionName = ruleCollectionName ?: throw PulumiNullFieldException("ruleCollectionName"),
        ruleName = ruleName ?: throw PulumiNullFieldException("ruleName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/GetDefaultAdminRulePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.GetDefaultAdminRulePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property configurationName The name of the network manager Security Configuration.
 * @property networkManagerName The name of the network manager.
 * @property resourceGroupName The name of the resource group.
 * @property ruleCollectionName The name of the network manager security Configuration rule collection.
 * @property ruleName The name of the rule.
 */
public data class GetDefaultAdminRulePlainArgs(
    public val configurationName: String,
    public val networkManagerName: String,
    public val resourceGroupName: String,
    public val ruleCollectionName: String,
    public val ruleName: String,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.GetDefaultAdminRulePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.GetDefaultAdminRulePlainArgs =
        com.pulumi.azurenative.network.inputs.GetDefaultAdminRulePlainArgs.builder()
            .configurationName(configurationName.let({ args0 -> args0 }))
            .networkManagerName(networkManagerName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .ruleCollectionName(ruleCollectionName.let({ args0 -> args0 }))
            .ruleName(ruleName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetDefaultAdminRulePlainArgs].
 */
@PulumiTagMarker
public class GetDefaultAdminRulePlainArgsBuilder internal constructor() {
    private var configurationName: String? = null

    private var networkManagerName: String? = null

    private var resourceGroupName: String? = null

    private var ruleCollectionName: String? = null

    private var ruleName: String? = null

    /**
     * @param value The name of the network manager Security Configuration.
     */
    @JvmName("jtovjijdvdetqsrs")
    public suspend fun configurationName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.configurationName = mapped
    }

    /**
     * @param value The name of the network manager.
     */
    @JvmName("wpslicpasmrepsyb")
    public suspend fun networkManagerName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.networkManagerName = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("hrabjjirsmemsxuy")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the network manager security Configuration rule collection.
     */
    @JvmName("yfwuajhjklvfibpd")
    public suspend fun ruleCollectionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.ruleCollectionName = mapped
    }

    /**
     * @param value The name of the rule.
     */
    @JvmName("hsksdknuxuvtrcwr")
    public suspend fun ruleName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.ruleName = mapped
    }

    internal fun build(): GetDefaultAdminRulePlainArgs = GetDefaultAdminRulePlainArgs(
        configurationName = configurationName ?: throw PulumiNullFieldException("configurationName"),
        networkManagerName = networkManagerName ?: throw PulumiNullFieldException("networkManagerName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        ruleCollectionName = ruleCollectionName ?: throw PulumiNullFieldException("ruleCollectionName"),
        ruleName = ruleName ?: throw PulumiNullFieldException("ruleName"),
    )
}
